@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2012   Lukas F. Reichlin
+## Copyright (C) 2010-2014   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
-## Version: 0.3
+## Version: 0.4
 
-function flg = eq (a, b)
+function bool = eq (a, b)
 
   if (nargin != 2)
     error ("quaternion: eq: this is a binary operator");
@@ -29,6 +29,13 @@ function flg = eq (a, b)
   a = quaternion (a);
   b = quaternion (b);
 
-  flg = size_equal (a, b) && (a.w == b.w) && (a.x == b.x) && (a.y == b.y) && (a.z == b.z);
+  bool = (a.w == b.w) & (a.x == b.x) & (a.y == b.y) & (a.z == b.z);
 
 endfunction
+
+
+%!test
+%! a = quaternion (2, 3, 4, 5);
+%! b = quaternion (2, -3, 4, 5);
+%! assert (a == a, true);
+%! assert (a == b, false);
