@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2010-2014   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -14,20 +14,20 @@
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{flg} =} ispure (@var{q})
-## Return 1 if scalar part of quaternion is zero, otherwise return 0
+## @deftypefn {Function File} {@var{bool} =} ispure (@var{q})
+## Return true if scalar part of quaternion is zero, otherwise return false.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
 ## Version: 0.1
 
-function flg = ispure (a)
+function bool = ispure (a)
 
   if (nargin != 1)
     print_usage ();
   endif
 
-  flg = all ((abs (a.w) < eps)(:));
+  bool = all ((abs (a.w) < eps)(:));
 
 endfunction
