@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011   Lukas F. Reichlin
+## Copyright (C) 2010-2014   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
-## Version: 0.2
+## Version: 0.3
 
 function q = quaternion (a, b, c, d)
 
@@ -84,7 +84,7 @@ function q = quaternion (a, b, c, d)
         q = a;
         return;
       elseif (is_real_array (a))        # quaternion (w)
-        b = c = d = zeros (size (a));
+        b = c = d = zeros (size (a), class (a));
       else
         print_usage ();
       endif
@@ -92,7 +92,7 @@ function q = quaternion (a, b, c, d)
       d = c;
       c = b;
       b = a;
-      a = zeros (size (a));
+      a = zeros (size (a), class (a));
     case 4                              # quaternion (w, x, y, z)
       ## nothing to do here, just prevent case "otherwise"
     otherwise
