@@ -1,4 +1,4 @@
-## Copyright (C) 2011   Lukas F. Reichlin
+## Copyright (C) 2010-2014   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ function q = subsasgn (q, idx, val)
         error ("quaternion: subsasgn: invalid argument type, require real array");
       endif
       if (! size_equal (subsref (q.w, idx(2:end)), val))
-        error ("quaternion: subsasgn: invalid argument size [%s], require dimensions [%s]", \
+        error ("quaternion: subsasgn: invalid argument size [%s], require dimensions [%s]", ...
                num2str (size (val), "%d "), num2str (size (subsref (q.w, idx(2:end))), "%d "));
       endif
       switch (tolower (idx(1).subs))
