@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011, 2012   Lukas F. Reichlin
+## Copyright (C) 2010-2014   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
-## Version: 0.4
+## Version: 0.5
 
 function ret = subsref (q, s)
 
@@ -39,7 +39,7 @@ function ret = subsref (q, s)
         case {"z", "k"}
           ret = subsref (q.z, s(2:end));
         case "v"                            # vector part, scalar part set to zero
-          q.w = zeros (size (q.w));
+          q.w = zeros (size (q.w), class (q.w));
           ret = subsref (q, s(2:end));
         otherwise
           error ("quaternion: invalid subscript name '%s'", s(1).subs);
